==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/entity/EntityMixin.java <==
package cc.thonly.reverie_dreams.mixin.entity;

import net.minecraft.class_1297;
import net.minecraft.class_1937;
import net.minecraft.class_5712;
import net.minecraft.class_6880;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;

@Mixin(class_1297.class)
public abstract class EntityMixin{
    @Shadow public abstract boolean isAlive();

    @Shadow public abstract class_1937 getWorld();

    @Shadow public abstract void emitGameEvent(class_6880<class_5712> event, @Nullable class_1297 entity);

//    @Inject(method = "interact", at = @At("HEAD"), cancellable = true)
//    public void interact(PlayerEntity entity, Hand hand, CallbackInfoReturnable<ActionResult> cir) {
//        Entity entity;
//        if (this.isAlive() && (entity = (Entity) (Object)this) instanceof Leashable) {
//            Leashable leashable = (Leashable)((Object)entity);
//            System.out.println(0);
//            if (leashable.getLeashHolder() == entity) {
//                System.out.println(1);
//                if (!this.getWorld().isClient()) {
//                    System.out.println(2);
//                    if (entity.isInCreativeMode()) {
//                        System.out.println(3);
//                        leashable.detachLeashWithoutDrop();
//                    } else {
//                        System.out.println(4);
//                        leashable.detachLeash();
//                    }
//                    this.emitGameEvent(GameEvent.ENTITY_INTERACT, entity);
//                }
//                cir.setReturnValue(ActionResult.SUCCESS.noIncrementStat());
//            }
//            ItemStack itemStack = entity.getStackInHand(hand);
//            if (itemStack.isOf(ItemTypeTag.LEAD) && leashable.canLeashAttachTo()) {
//                System.out.println(5);
//                if (!this.getWorld().isClient()) {
//                    System.out.println(6);
//                    leashable.attachLeash(entity, true);
//                }
//                itemStack.decrement(1);
//                cir.setReturnValue(ActionResult.SUCCESS);
//            }
//        }
//        cir.setReturnValue(ActionResult.PASS);
//    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/entity/EntityMixin.java <==
package cc.thonly.reverie_dreams.mixin.entity;

import net.minecraft.class_1297;
import net.minecraft.class_1937;
import net.minecraft.class_5712;
import net.minecraft.class_6880;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;

@Mixin(class_1297.class)
public abstract class EntityMixin{
    @Shadow public abstract boolean isAlive();

    @Shadow public abstract class_1937 level();

    @Shadow public abstract void gameEvent(class_6880<class_5712> event, @Nullable class_1297 entity);

//    @Inject(method = "interact", at = @At("HEAD"), cancellable = true)
//    public void interact(PlayerEntity entity, Hand hand, CallbackInfoReturnable<ActionResult> cir) {
//        Entity entity;
//        if (this.isAlive() && (entity = (Entity) (Object)this) instanceof Leashable) {
//            Leashable leashable = (Leashable)((Object)entity);
//            System.out.println(0);
//            if (leashable.getLeashHolder() == entity) {
//                System.out.println(1);
//                if (!this.getWorld().isClient()) {
//                    System.out.println(2);
//                    if (entity.isInCreativeMode()) {
//                        System.out.println(3);
//                        leashable.detachLeashWithoutDrop();
//                    } else {
//                        System.out.println(4);
//                        leashable.detachLeash();
//                    }
//                    this.emitGameEvent(GameEvent.ENTITY_INTERACT, entity);
//                }
//                cir.setReturnValue(ActionResult.SUCCESS.noIncrementStat());
//            }
//            ItemStack itemStack = entity.getStackInHand(hand);
//            if (itemStack.isOf(ItemTypeTag.LEAD) && leashable.canLeashAttachTo()) {
//                System.out.println(5);
//                if (!this.getWorld().isClient()) {
//                    System.out.println(6);
//                    leashable.attachLeash(entity, true);
//                }
//                itemStack.decrement(1);
//                cir.setReturnValue(ActionResult.SUCCESS);
//            }
//        }
//        cir.setReturnValue(ActionResult.PASS);
//    }
}
